![vandal-header](https://raw.githubusercontent.com/dkundih/vandal/main/.logistics/visforvandalpy.jpg)

**vandal is currently an archived package, while all the functionality has been merged into duality package**

![duality-header](https://raw.githubusercontent.com/dkundih/duality/main/.logistics/duality.jpg)

**visit https://pypi.org/project/duality/ or https://github.com/dkundih/duality for more details**